@@ -15,12 +15,10 @@ from airbyte_cdk.connector import Connector
 from airbyte_cdk.exception_handler import init_uncaught_exception_handler
 from airbyte_cdk.models import (
     AirbyteMessage,
+    AirbyteMessageSerializer,
     ConfiguredAirbyteCatalog,
+    ConfiguredAirbyteCatalogSerializer,
     Type,
-    ab_configured_catalog_from_string,
-    ab_configured_catalog_to_string,
-    ab_message_from_string,
-    ab_message_to_string,
 )
 from airbyte_cdk.sources.utils.schema_helpers import check_config_against_spec_or_exit
 from airbyte_cdk.utils.traced_exception import AirbyteTracedException
@@ -48,7 +46,7 @@ class Destination(Connector, ABC):
         """Reads from stdin, converting to Airbyte messages"""
         for line in input_stream:
             try:
-                yield ab_message_from_string(line)
+                yield AirbyteMessageSerializer.load(orjson.loads(line))
             except orjson.JSONDecodeError:
                 logger.info(
                     f"ignoring input which can't be deserialized as Airbyte Message: {line}"
@@ -60,7 +58,9 @@ class Destination(Connector, ABC):
         configured_catalog_path: str,
         input_stream: io.TextIOWrapper,
     ) -> Iterable[AirbyteMessage]:
-        catalog = ab_configured_catalog_from_string(open(configured_catalog_path).read())
+        catalog = ConfiguredAirbyteCatalogSerializer.load(
+            orjson.loads(open(configured_catalog_path).read())
+        )
         input_messages = self._parse_input_stream(input_stream)
         logger.info("Begin writing to the destination...")
         yield from self.write(
@@ -151,4 +151,4 @@ class Destination(Connector, ABC):
         parsed_args = self.parse_args(args)
         output_messages = self.run_cmd(parsed_args)
         for message in output_messages:
-            print(ab_message_to_string(message))
+            print(orjson.dumps(AirbyteMessageSerializer.dump(message)).decode())
